@@ -55,6 +55,20 @@ class Errorable:
                 self.Error(field, value,
                            type(exc).__name__ if exc else None, str(exc)))
 
+    def _check_str(self, name, value):
+        """helper method to check for a valid string parameter being set."""
+        if value is not None:
+            if not isinstance(value, str):
+                self.err(
+                    name, value,
+                    TypeError(f"The {self.typename} '{name}' must be of type string."))
+                return False
+            if value == "":
+                self.err(name, value,
+                         f"The {self.typename} '{name}' must be non-empty.")
+                return False
+        return True
+
 
 class Repeated(Errorable):
     """Class to make a "repeated" protobuf attribute pythonic."""
@@ -124,6 +138,7 @@ class Repeated(Errorable):
 
 class Attachment(Errorable):
     """A Service Attachment object that can be easily manimulated in Python."""
+    typename = 'attachment'
     __slots__ = ["pb", "_mac_addresses", "_network_prefixes"]
 
     def __init__(self, pb=None, **kwargs):
@@ -162,18 +177,11 @@ class Attachment(Errorable):
 
     @imsi.setter
     def imsi(self, value):
-        if value is not None:
-            if not isinstance(value, str):
-                self.err('imsi', value,
-                         TypeError("The 'imsi' parameter must be of type string."))
-                return
-            if value == "":
-                self.err('imsi', value,
-                         TypeError("The 'imsi' parameter must be non-empty."))
-                return
-            self.pb.imsi = str(value)
-        else:
-            self.pb.ClearField('imsi')
+        if self._check_str('imsi', value):
+            if value is not None:
+                self.pb.imsi = value
+            else:
+                self.pb.ClearField('imsi')
 
     @property
     def cpe_serial_number(self):
@@ -182,21 +190,11 @@ class Attachment(Errorable):
 
     @cpe_serial_number.setter
     def cpe_serial_number(self, value):
-        if value is not None:
-            if not isinstance(value, str):
-                self.err(
-                    'cpe_serial_number', value,
-                    TypeError(
-                        "The 'cpe_serial_number' parameter must be of type string."))
-                return
-            if value == "":
-                self.err(
-                    'cpe_serial_number', value,
-                    TypeError("The 'cpe_serial_number' parameter must be non-empty."))
-                return
-            self.pb.cpe_serial_number = str(value)
-        else:
-            self.pb.ClearField('cpe_serial_number')
+        if self._check_str('cpe_serial_number', value):
+            if value is not None:
+                self.pb.cpe_serial_number = value
+            else:
+                self.pb.ClearField('cpe_serial_number')
 
     @property
     def cpe_name(self):
@@ -204,18 +202,11 @@ class Attachment(Errorable):
 
     @cpe_name.setter
     def cpe_name(self, value):
-        if value is not None:
-            if not isinstance(value, str):
-                self.err('cpe_name', value,
-                         TypeError("The 'cpe_name' parameter must be of type string."))
-                return
-            if value == "":
-                self.err('cpe_name', value,
-                         TypeError("The 'cpe_name' parameter must be non-empty."))
-                return
-            self.pb.cpe_name = str(value)
-        else:
-            self.pb.ClearField('cpe_name')
+        if self._check_str('cpe_name', value):
+            if value is not None:
+                self.pb.cpe_name = str(value)
+            else:
+                self.pb.ClearField('cpe_name')
 
     @property
     def device_mac_address(self):
@@ -471,20 +462,8 @@ class BaseNetworkElement(Errorable):
 
     @community.setter
     def community(self, value):
-        if value is not None:
-            if not isinstance(value, str):
-                self.err(
-                    'community', value,
-                    TypeError(
-                        f"The {self.typename} 'community' parameter must be of type string."
-                    ))
-                return
-            if value == "":
-                self.err(
-                    'community', value,
-                    f"The {self.typename} 'community' parameter must be non-empty.")
-                return
-        self._community = str(value) if value is not None else None
+        if self._check_str('community', value):
+            self._community = str(value) if value is not None else None
 
     @property
     def host(self):
@@ -506,19 +485,8 @@ class BaseNetworkElement(Errorable):
 
     @name.setter
     def name(self, value):
-        if value is not None:
-            if not isinstance(value, str):
-                self.err(
-                    'name', value,
-                    TypeError(
-                        f"The {self.typename} 'name' parameter must be of type string.")
-                )
-                return
-            if value == "":
-                self.err('name', value,
-                         f"The {self.typename} 'name' parameter must be non-empty.")
-                return
-        self._name = str(value) if value is not None else None
+        if self._check_str('name', value):
+            self._name = str(value) if value is not None else None
 
     @property
     def site(self):
@@ -526,19 +494,8 @@ class BaseNetworkElement(Errorable):
 
     @site.setter
     def site(self, value):
-        if value is not None:
-            if not isinstance(value, str):
-                self.err(
-                    'site', value,
-                    TypeError(
-                        f"The {self.typename} 'site' parameter must be of type string.")
-                )
-                return
-            if value == "":
-                self.err('site', value,
-                         f"The {self.typename} 'site' parameter must be non-empty.")
-                return
-        self._site = str(value) if value is not None else None
+        if self._check_str('site', value):
+            self._site = str(value) if value is not None else None
 
     @property
     def url(self):
@@ -546,16 +503,8 @@ class BaseNetworkElement(Errorable):
 
     @url.setter
     def url(self, value):
-        if value is not None:
-            if not isinstance(value, str):
-                self.err('url', value,
-                         f"The {self.typename} 'url' parameter must be a string.")
-                return
-            if value == "":
-                self.err('url', value,
-                         f"The {self.typename} 'url' parameter must be non-empty.")
-                return
-        self._url = value if value is not None else None
+        if self._check_str('url', value):
+            self._url = value if value is not None else None
 
     def __repr__(self):
         attr_values = [(attr, getattr(self, attr)) for attr in self.attrs]
